==> DuHast-1.1.3.tar.gz: DuHast-1.1.3/src/duHast/Data/Objects/data_base.py <==
"""
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Data base class for Revit object properties.
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
"""

#
# License:
#
#
# Revit Batch Processor Sample Code
#
# BSD License
# Copyright 2023, Jan Christel
# All rights reserved.

# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

# - Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
# - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
# - Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
#
# This software is provided by the copyright holder "as is" and any express or implied warranties, including, but not limited to, the implied warranties of merchantability and fitness for a particular purpose are disclaimed.
# In no event shall the copyright holder be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, but not limited to, procurement of substitute goods or services; loss of use, data, or profits;
# or business interruption) however caused and on any theory of liability, whether in contract, strict liability, or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damage.
#
#
#

from duHast.Utilities.Objects import base


class DataBase(base.Base):
    def __init__(self, data_type, **kwargs):
        """
        Class constructor

        :param data_type: human readable data type
        :type data_type: str
        """

        # forwards all unused arguments
        # ini super class to allow multi inheritance in children!
        super(DataBase, self).__init__(**kwargs)
        self.data_type = data_type

    @property
    def DataType(self):
        """
        Property: returns the data type of this class.

        :return:  A string representing the data type
        :rtype: str
        """

        return self.data_type

==> DuHast-1.1.6.tar.gz: DuHast-1.1.6/src/duHast/Data/Objects/data_base.py <==
"""
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Data base class for Revit object properties.
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
"""

#
# License:
#
#
# Revit Batch Processor Sample Code
#
# BSD License
# Copyright 2023, Jan Christel
# All rights reserved.

# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

# - Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
# - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
# - Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
#
# This software is provided by the copyright holder "as is" and any express or implied warranties, including, but not limited to, the implied warranties of merchantability and fitness for a particular purpose are disclaimed.
# In no event shall the copyright holder be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, but not limited to, procurement of substitute goods or services; loss of use, data, or profits;
# or business interruption) however caused and on any theory of liability, whether in contract, strict liability, or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damage.
#
#
#

from duHast.Utilities.Objects.base import Base


class DataBase(Base):
    def __init__(self, data_type, **kwargs):
        """
        Class constructor

        :param data_type: human readable data type
        :type data_type: str
        """

        # forwards all unused arguments
        # ini super class to allow multi inheritance in children!
        super(DataBase, self).__init__(**kwargs)
        self.data_type = data_type
        if isinstance(self.data_type, str) == False:
            raise TypeError(
                "data_type must be a string, got {} instead.".format(type(data_type))
            )

    @property
    def DataType(self):
        """
        Property: returns the data type of this class.

        :return:  A string representing the data type
        :rtype: str
        """

        return self.data_type

    def __eq__(self, other):
        if not isinstance(other, DataBase):
            return NotImplemented
        return self.DataType == other.DataType

    def __ne__(self, other):
        return not self.__eq__(other)
